﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web.Mvc;

namespace Cuyahoga.Web.MVC.ViewComponents
{
	public static class ViewComponentExtensions
	{
		/// <summary>
		/// Renders a self-containing partial view. Use RenderUserControl if you only need some generic view.
		/// </summary>
		/// <param name="htmlHelper"></param>
		/// <param name="componentName"></param>
		/// <returns></returns>
		public static string RenderViewComponent(this HtmlHelper htmlHelper, string componentName)
		{
			return RenderViewComponent(htmlHelper, componentName, null);
		}

		/// <summary>
		/// Renders a self-containing partial view. Use RenderUserControl if you only need some generic view.
		/// </summary>
		/// <param name="htmlHelper"></param>
		/// <param name="componentName"></param>
		/// <param name="viewData"></param>
		/// <returns></returns>
		public static string RenderViewComponent(this HtmlHelper htmlHelper, string componentName, object viewData)
		{
			IViewComponent viewComponent = ViewComponentBuilder.Current.CreateViewComponent(componentName);
			viewComponent.Init(htmlHelper.ViewContext, viewData);
			return viewComponent.Render();
		}
	}
}
