﻿using System.Web.Mvc;
using Cuyahoga.Web.MVC.Windsor;
using Castle.Core.Logging;
using Cuyahoga.Core.Util;
using Cuyahoga.Web.Manager.Models;
using System;
using Castle.Components.Validator;
using System.Text;
using Cuyahoga.Web.Manager.Helpers;

namespace Cuyahoga.Web.Manager.Controllers
{
	public abstract class BaseController : Controller, IWindsorController
	{
		private ILogger _logger;
		private IValidatorRegistry _validatorRegistry;
		private ValidatorRunner _validatorRunner;

		/// <summary>
		/// 
		/// </summary>
		public ILogger Logger
		{
			get { return this._logger; }
		}

		/// <summary>
		/// 
		/// </summary>
		protected MessageData Messages
		{
			get { return (MessageData)ViewData["Messages"]; }
		}

		/// <summary>
		/// 
		/// </summary>
		public IValidatorRegistry ValidatorRegistry
		{
			set { this._validatorRegistry = value; }
		}

		/// <summary>
		/// 
		/// </summary>
		public ValidatorRunner ValidatorRunner
		{
			get { return this._validatorRunner; }
		}

		/// <summary>
		/// 
		/// </summary>
		public BaseController()
		{
			ILoggerFactory loggerFactory = IoC.Resolve<ILoggerFactory>();
			if (loggerFactory != null)
			{
				this._logger = loggerFactory.Create(GetType().Name);
			}
		}

		protected override bool OnPreAction(string actionName, System.Reflection.MethodInfo methodInfo)
		{
			if (TempData.ContainsKey("Messages"))
			{
				ViewData["Messages"] = TempData["Messages"];
			}
			else
			{
				ViewData["Messages"] = new MessageData();
			}

			this._validatorRunner = new ValidatorRunner(this._validatorRegistry);

			return base.OnPreAction(actionName, methodInfo);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="message"></param>
		public void ShowMessage(string message)
		{
			ShowMessage(message, false);	
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="message"></param>
		/// <param name="displayAfterRedirect"></param>
		public void ShowMessage(string message, bool displayAfterRedirect)
		{
			Messages.Message = message;
			PersistMessageData(displayAfterRedirect);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="message"></param>
		public void ShowError(string message)
		{
			ShowError(message, false);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="message"></param>
		/// <param name="displayAfterRedirect"></param>
		public void ShowError(string message, bool displayAfterRedirect)
		{
			Messages.Error = message;
			PersistMessageData(displayAfterRedirect);
		}

		public void ShowError(ErrorSummary errorSummary)
		{
			ShowError(errorSummary, false);
		}

		public void ShowError(ErrorSummary errorSummary, bool displayAfterRedirect)
		{
			string errorMessage = CreateErrorMessageFromErrorSummary(errorSummary);
			ShowError(errorMessage, displayAfterRedirect);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="ex"></param>
		public void ShowException(Exception ex)
		{
			ShowException(ex, false);
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="ex"></param>
		/// <param name="displayAfterRedirect"></param>
		public void ShowException(Exception ex, bool displayAfterRedirect)
		{
			Messages.Exception = ex;
			PersistMessageData(displayAfterRedirect);
		}

		private void PersistMessageData(bool displayAfterRedirect)
		{
			if (displayAfterRedirect)
			{
				TempData["Messages"] = Messages;
			}
		}

		private string CreateErrorMessageFromErrorSummary(ErrorSummary errorSummary)
		{
			StringBuilder sb = new StringBuilder();
			foreach (string propertyName in errorSummary.InvalidProperties)
			{
				foreach (string errorMessage in errorSummary.GetErrorsForProperty(propertyName))
				{
					sb.AppendFormat("{0}<br />", ResourceHelper.GetGlobalText(errorMessage));
				}
			}
			return sb.ToString();
		}
	}
}
