﻿using System;
using System.Web;
using System.Web.Mvc;
using Cuyahoga.Core.Domain;
using Cuyahoga.Core.Service.Membership;
using System.Web.Security;
using System.Security.Authentication;
using Cuyahoga.Web.Manager.Models;

namespace Cuyahoga.Web.Manager.Controllers
{
	public class LoginController : BaseController
	{
		private IAuthenticationService _authenticationService;

		/// <summary>
		/// Constructor.
		/// </summary>
		/// <param name="authenticationService"></param>
		public LoginController(IAuthenticationService authenticationService)
		{
			this._authenticationService = authenticationService;
		}

		[ControllerAction]
		public void Index(string returnurl)
		{
			ViewData["returnurl"] = returnurl;
			if (TempData.ContainsKey("username"))
			{
				ViewData["username"] = TempData["username"];
			}
			RenderView("Index", "Base");
		}

		[ControllerAction]
		public void Login(string username, string password, string returnUrl)
		{
			try
			{
				User user = this._authenticationService.AuthenticateUser(username, password, Request.UserHostAddress);

				FormsAuthentication.SetAuthCookie(user.Id.ToString(), false);
				if (! String.IsNullOrEmpty(returnUrl))
				{
					Response.Redirect(returnUrl);
				}
				else
				{
					RedirectToAction(new { controller = "Dashboard", action = "Index" });
				}

				return;
			}
			catch (AuthenticationException ex)
			{
				ShowException(ex, true);
				TempData["username"] = username;
				// We'd rather want to use RedirectToAction, but it seems pretty impossible 
				// at this moment to add extra parameters for the querystring (like returnUrl).
				Response.Redirect("~/Login/Index?returnurl=" + returnUrl);
			}
		}

		[ControllerAction]
		public void Logout()
		{
			FormsAuthentication.SignOut();
			RedirectToAction(new { controller = "Login", action = "Index" });
		}
	}
}
