﻿using System.Collections.Generic;
using System.Web.Mvc;
using Cuyahoga.Core.Domain;
using Cuyahoga.Web.Manager.Models;
using Cuyahoga.Web.MVC;
using Cuyahoga.Web.MVC.ViewComponents;
using Resources;

namespace Cuyahoga.Web.Manager.ViewComponents
{
	/// <summary>
	/// View component that is responsible for displaying the main menu.
	/// </summary>
	public class MainMenuComponent : ViewComponent
	{
		private ICuyahogaContext _cuyahogaContext;

		/// <summary>
		/// Constructor.
		/// </summary>
		/// <remarks>
		/// This viewcomponent can be created by an IoC container where the IoC container 
		/// supplies the ICuyahogaContext.
		/// </remarks>
		/// <param name="cuyahogaContext"></param>
		public MainMenuComponent(ICuyahogaContext cuyahogaContext)
		{
			this._cuyahogaContext = cuyahogaContext;
		}

		/// <summary>
		/// Initialize view component data.
		/// </summary>
		public override void Initialize()
		{
			GenerateMenuData(this._cuyahogaContext.CurrentUser);
		}

		private void GenerateMenuData(User user)
		{
			List<MenuItemData> standardMenuItems = new List<MenuItemData>();
			List<MenuItemData> optionalMenuItems = new List<MenuItemData>();

			UrlHelper urlHelper = new UrlHelper(this.CurrentViewContext);

			if (user != null && user.IsAuthenticated)
			{
				standardMenuItems.Add(
					new MenuItemData(urlHelper.Action("Index", "Dashboard"), GlobalResources.ManagerMenuDashboard, CheckInPath("Dashboard")));
				standardMenuItems.Add(
					new MenuItemData(urlHelper.Action("Index", "Pages"), GlobalResources.ManagerMenuPages, CheckInPath("Pages")));
				standardMenuItems.Add(
					new MenuItemData(urlHelper.Action("Index", "Files"), GlobalResources.ManagerMenuFiles, CheckInPath("Files")));
				if (user.HasRight("Manage Users"))
				{
					optionalMenuItems.Add(new MenuItemData(urlHelper.Action("Index", "Users"), GlobalResources.ManagerMenuUsers, CheckInPath("Users")));
				}
				if (user.HasRight("Manage Site"))
				{
					optionalMenuItems.Add(new MenuItemData(urlHelper.Action("Index", "Site"), GlobalResources.ManagerMenuSite, CheckInPath("Site")));
				}
				if (user.HasRight("Manage Server"))
				{
					optionalMenuItems.Add(new MenuItemData(urlHelper.Action("Index", "Server"), GlobalResources.ManagerMenuServer, CheckInPath("Server")));
				}
			}
			ViewComponentData["StandardMenuItems"] = standardMenuItems;
			ViewComponentData["OptionalMenuItems"] = optionalMenuItems;
		}

		private bool CheckInPath(string controllerName)
		{
			return this.CurrentViewContext.RouteData.Values["controller"].ToString().ToLower().Contains(controllerName.ToLower());
		}
	}
}
